==> haskell-hackage-security-0.6.2.6-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hackage-security.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hackage-security
version:              0.6.2.6
visibility:           public
id:                   hackage-security-0.6.2.6-8IZR5bjEs7dBPHZfb2Fkav
key:                  hackage-security-0.6.2.6-8IZR5bjEs7dBPHZfb2Fkav
license:              BSD-3-Clause
copyright:            Copyright 2015-2022 Well-Typed LLP
maintainer:           cabal-devel@haskell.org
author:               Edsko de Vries
homepage:             https://github.com/haskell/hackage-security
synopsis:             Hackage security library
description:
    The hackage security library provides both server and
    client utilities for securing the Hackage package server
    (<https://hackage.haskell.org/>).  It is based on The Update
    Framework (<https://theupdateframework.com/>), a set of
    recommendations developed by security researchers at
    various universities in the US as well as developers on the
    Tor project (<https://www.torproject.org/>).

    The current implementation supports only index signing,
    thereby enabling untrusted mirrors. It does not yet provide
    facilities for author package signing.

    The library has two main entry points:
    "Hackage.Security.Client" is the main entry point for
    clients (the typical example being @cabal@), and
    "Hackage.Security.Server" is the main entry point for
    servers (the typical example being @hackage-server@).

category:             Distribution
abi:                  95a0bb982a3eac03aa349cdf3052c8cc
exposed:              True
exposed-modules:
    Hackage.Security.Client Hackage.Security.Client.Formats
    Hackage.Security.Client.Repository
    Hackage.Security.Client.Repository.Cache
    Hackage.Security.Client.Repository.HttpLib
    Hackage.Security.Client.Repository.Local
    Hackage.Security.Client.Repository.Remote
    Hackage.Security.Client.Verify Hackage.Security.JSON
    Hackage.Security.Key.Env Hackage.Security.Server
    Hackage.Security.TUF.FileMap Hackage.Security.Trusted
    Hackage.Security.Util.Checked Hackage.Security.Util.Path
    Hackage.Security.Util.Pretty Hackage.Security.Util.Some
    Text.JSON.Canonical

hidden-modules:
    Hackage.Security.Key Hackage.Security.Trusted.TCB
    Hackage.Security.TUF Hackage.Security.TUF.Common
    Hackage.Security.TUF.FileInfo Hackage.Security.TUF.Header
    Hackage.Security.TUF.Layout.Cache Hackage.Security.TUF.Layout.Index
    Hackage.Security.TUF.Layout.Repo Hackage.Security.TUF.Mirrors
    Hackage.Security.TUF.Paths Hackage.Security.TUF.Patterns
    Hackage.Security.TUF.Root Hackage.Security.TUF.Signed
    Hackage.Security.TUF.Snapshot Hackage.Security.TUF.Targets
    Hackage.Security.TUF.Timestamp Hackage.Security.Util.Base64
    Hackage.Security.Util.Exit Hackage.Security.Util.IO
    Hackage.Security.Util.JSON Hackage.Security.Util.Lens
    Hackage.Security.Util.Stack Hackage.Security.Util.TypedEmbedded

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hackage-security-0.6.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hackage-security-0.6.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hackage-security-0.6.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hackage-security
hs-libraries:         HShackage-security-0.6.2.6-8IZR5bjEs7dBPHZfb2Fkav
depends:
    Cabal-syntax-3.8.1.0 base-4.17.2.1
    base16-bytestring-1.0.2.0-DtLhCS1yMgY3iFYZkoZd12
    base64-bytestring-1.2.1.0-LY9UF0mrytX7ReHq71Oo2M
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-JuksYLM6warBHNj9levj9A
    directory-1.3.7.1 ed25519-0.0.5.0-8644XuUf7h2DKMAvPBqI1l
    filepath-1.4.2.2 ghc-prim-0.9.1
    lukko-0.1.1.3-A5oU8Mr2wn4DKRXEqR14qa mtl-2.2.2
    network-3.1.4.0-KV3OkCyx0pcI1DdyD3ZbeB
    network-uri-2.6.4.2-2s4BpOjYszS9lLOXbJJXzp parsec-3.1.16.1
    pretty-1.1.3.6 tar-0.5.1.1-DqOlwhHwfBU9MyAlZvh6c1
    template-haskell-2.19.0.0 time-1.12.2 transformers-0.5.6.2
    zlib-0.7.0.0-ETKhfsRrhPuJs6VMW6KGUO

haddock-interfaces:
    /usr/share/doc/haskell-hackage-security/html/hackage-security.haddock

haddock-html:         /usr/share/doc/haskell-hackage-security/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hackage-security-0.6.2.6-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hackage-security.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hackage-security
version:              0.6.2.6
visibility:           public
id:                   hackage-security-0.6.2.6-56dJ9HD9oDz4cWWdrmrV0r
key:                  hackage-security-0.6.2.6-56dJ9HD9oDz4cWWdrmrV0r
license:              BSD-3-Clause
copyright:            Copyright 2015-2022 Well-Typed LLP
maintainer:           cabal-devel@haskell.org
author:               Edsko de Vries
homepage:             https://github.com/haskell/hackage-security
synopsis:             Hackage security library
description:
    The hackage security library provides both server and
    client utilities for securing the Hackage package server
    (<https://hackage.haskell.org/>).  It is based on The Update
    Framework (<https://theupdateframework.com/>), a set of
    recommendations developed by security researchers at
    various universities in the US as well as developers on the
    Tor project (<https://www.torproject.org/>).

    The current implementation supports only index signing,
    thereby enabling untrusted mirrors. It does not yet provide
    facilities for author package signing.

    The library has two main entry points:
    "Hackage.Security.Client" is the main entry point for
    clients (the typical example being @cabal@), and
    "Hackage.Security.Server" is the main entry point for
    servers (the typical example being @hackage-server@).

category:             Distribution
abi:                  72c1c1742a15cf1d773482a8f6b8961c
exposed:              True
exposed-modules:
    Hackage.Security.Client Hackage.Security.Client.Formats
    Hackage.Security.Client.Repository
    Hackage.Security.Client.Repository.Cache
    Hackage.Security.Client.Repository.HttpLib
    Hackage.Security.Client.Repository.Local
    Hackage.Security.Client.Repository.Remote
    Hackage.Security.Client.Verify Hackage.Security.JSON
    Hackage.Security.Key.Env Hackage.Security.Server
    Hackage.Security.TUF.FileMap Hackage.Security.Trusted
    Hackage.Security.Util.Checked Hackage.Security.Util.Path
    Hackage.Security.Util.Pretty Hackage.Security.Util.Some
    Text.JSON.Canonical

hidden-modules:
    Hackage.Security.Key Hackage.Security.Trusted.TCB
    Hackage.Security.TUF Hackage.Security.TUF.Common
    Hackage.Security.TUF.FileInfo Hackage.Security.TUF.Header
    Hackage.Security.TUF.Layout.Cache Hackage.Security.TUF.Layout.Index
    Hackage.Security.TUF.Layout.Repo Hackage.Security.TUF.Mirrors
    Hackage.Security.TUF.Paths Hackage.Security.TUF.Patterns
    Hackage.Security.TUF.Root Hackage.Security.TUF.Signed
    Hackage.Security.TUF.Snapshot Hackage.Security.TUF.Targets
    Hackage.Security.TUF.Timestamp Hackage.Security.Util.Base64
    Hackage.Security.Util.Exit Hackage.Security.Util.IO
    Hackage.Security.Util.JSON Hackage.Security.Util.Lens
    Hackage.Security.Util.Stack Hackage.Security.Util.TypedEmbedded

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hackage-security-0.6.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hackage-security-0.6.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hackage-security-0.6.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hackage-security
hs-libraries:         HShackage-security-0.6.2.6-56dJ9HD9oDz4cWWdrmrV0r
depends:
    Cabal-syntax-3.8.1.0 base-4.17.2.1
    base16-bytestring-1.0.2.0-C3cPjjLt0AO1rbHXbT6P0Z
    base64-bytestring-1.2.1.0-IbCUnYF5PxIJ57HxqijudZ
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-qCC3j6usTK8QvKkToMNCt
    directory-1.3.7.1 ed25519-0.0.5.0-8644XuUf7h2DKMAvPBqI1l
    filepath-1.4.2.2 ghc-prim-0.9.1
    lukko-0.1.1.3-IUbHCiHtCSsFV36lRZiNpg mtl-2.2.2
    network-3.1.4.0-9WwAYDZyp2nAB4XV6sI63l
    network-uri-2.6.4.2-6QHuxl9r30A5vsu5UpWUoB parsec-3.1.16.1
    pretty-1.1.3.6 tar-0.5.1.1-8bjTCpnjj2u7MPlg2iR2h1
    template-haskell-2.19.0.0 time-1.12.2 transformers-0.5.6.2
    zlib-0.7.0.0-ClmxrPWTDgrGZgFhkWmoWv

haddock-interfaces:
    /usr/share/doc/haskell-hackage-security/html/hackage-security.haddock

haddock-html:         /usr/share/doc/haskell-hackage-security/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
